@@ -21,7 +21,6 @@ var (
 		"certspotter",
 		"chaos",
 		"chinaz",
-		"columbus",
 		"commoncrawl",
 		"crtsh",
 		"digitorus",
@@ -34,7 +33,6 @@ var (
 		"hackertarget",
 		"intelx",
 		"netlas",
-		"passivetotal",
 		"quake",
 		"rapiddns",
 		"redhuntlabs",
@@ -44,6 +42,7 @@ var (
 		"shodan",
 		"sitedossier",
 		"threatbook",
+		"threatcrowd",
 		"virustotal",
 		"waybackarchive",
 		"whoisxmlapi",
@@ -54,7 +53,8 @@ var (
 		// "threatminer",
 		// "reconcloud",
 		"builtwith",
-		"subdomaincenter",
+		"hudsonrock",
+		"digitalyama",
 	}
 
 	expectedDefaultSources = []string{
@@ -67,7 +67,6 @@ var (
 		"censys",
 		"chaos",
 		"chinaz",
-		"columbus",
 		"crtsh",
 		"digitorus",
 		"dnsdumpster",
@@ -76,7 +75,6 @@ var (
 		"fullhunt",
 		"hackertarget",
 		"intelx",
-		"passivetotal",
 		"quake",
 		"redhuntlabs",
 		"robtex",
@@ -91,7 +89,7 @@ var (
 		// "threatminer",
 		// "reconcloud",
 		"builtwith",
-		"subdomaincenter",
+		"digitalyama",
 	}
 
 	expectedDefaultRecursiveSources = []string{
@@ -100,11 +98,9 @@ var (
 		"bufferover",
 		"certspotter",
 		"crtsh",
-		"dnsdumpster",
 		"dnsdb",
 		"digitorus",
 		"hackertarget",
-		"passivetotal",
 		"securitytrails",
 		"virustotal",
 		"leakix",
